You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@ignite.apache.org by pt...@apache.org on 2016/09/09 12:27:21 UTC

[1/2] ignite git commit: Rename cacheOp

Repository: ignite
Updated Branches:
  refs/heads/ignite-3199-1 f22c0a022 -> 0e2d51218


Rename cacheOp


Project: http://git-wip-us.apache.org/repos/asf/ignite/repo
Commit: http://git-wip-us.apache.org/repos/asf/ignite/commit/65e82ae0
Tree: http://git-wip-us.apache.org/repos/asf/ignite/tree/65e82ae0
Diff: http://git-wip-us.apache.org/repos/asf/ignite/diff/65e82ae0

Branch: refs/heads/ignite-3199-1
Commit: 65e82ae0deb0df674be8107c395cf391df1de39f
Parents: f22c0a0
Author: Pavel Tupitsyn <pt...@apache.org>
Authored: Fri Sep 9 15:26:21 2016 +0300
Committer: Pavel Tupitsyn <pt...@apache.org>
Committed: Fri Sep 9 15:26:21 2016 +0300

----------------------------------------------------------------------
 .../platforms/dotnet/Apache.Ignite.Core/Impl/Cache/CacheImpl.cs    | 2 +-
 modules/platforms/dotnet/Apache.Ignite.Core/Impl/Cache/CacheOp.cs  | 2 +-
 2 files changed, 2 insertions(+), 2 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/ignite/blob/65e82ae0/modules/platforms/dotnet/Apache.Ignite.Core/Impl/Cache/CacheImpl.cs
----------------------------------------------------------------------
diff --git a/modules/platforms/dotnet/Apache.Ignite.Core/Impl/Cache/CacheImpl.cs b/modules/platforms/dotnet/Apache.Ignite.Core/Impl/Cache/CacheImpl.cs
index 5172db4..75a4871 100644
--- a/modules/platforms/dotnet/Apache.Ignite.Core/Impl/Cache/CacheImpl.cs
+++ b/modules/platforms/dotnet/Apache.Ignite.Core/Impl/Cache/CacheImpl.cs
@@ -875,7 +875,7 @@ namespace Apache.Ignite.Core.Impl.Cache
         /** <inheritDoc /> */
         public T Invoke<T>(CacheInvokeOp opCode, Action<IBinaryRawWriter> writeAction)
         {
-            return DoOutInOpX((int) CacheOp.InvokeInternal, writer =>
+            return DoOutInOpX((int) CacheOp.Extension, writer =>
                 {
                     writer.WriteInt((int) opCode);
                     writeAction(writer);

http://git-wip-us.apache.org/repos/asf/ignite/blob/65e82ae0/modules/platforms/dotnet/Apache.Ignite.Core/Impl/Cache/CacheOp.cs
----------------------------------------------------------------------
diff --git a/modules/platforms/dotnet/Apache.Ignite.Core/Impl/Cache/CacheOp.cs b/modules/platforms/dotnet/Apache.Ignite.Core/Impl/Cache/CacheOp.cs
index 3ce16c3..e6ca938 100644
--- a/modules/platforms/dotnet/Apache.Ignite.Core/Impl/Cache/CacheOp.cs
+++ b/modules/platforms/dotnet/Apache.Ignite.Core/Impl/Cache/CacheOp.cs
@@ -62,6 +62,6 @@ namespace Apache.Ignite.Core.Impl.Cache
         Replace3 = 38,
         GetConfig = 39,
         LoadAll = 40,
-        InvokeInternal = 41
+        Extension = 41
     }
 }
\ No newline at end of file


[2/2] ignite git commit: rename to InvokeExtension

Posted by pt...@apache.org.
rename to InvokeExtension


Project: http://git-wip-us.apache.org/repos/asf/ignite/repo
Commit: http://git-wip-us.apache.org/repos/asf/ignite/commit/0e2d5121
Tree: http://git-wip-us.apache.org/repos/asf/ignite/tree/0e2d5121
Diff: http://git-wip-us.apache.org/repos/asf/ignite/diff/0e2d5121

Branch: refs/heads/ignite-3199-1
Commit: 0e2d51218d275f0e59b74897f2da8225048a52db
Parents: 65e82ae
Author: Pavel Tupitsyn <pt...@apache.org>
Authored: Fri Sep 9 15:27:07 2016 +0300
Committer: Pavel Tupitsyn <pt...@apache.org>
Committed: Fri Sep 9 15:27:07 2016 +0300

----------------------------------------------------------------------
 .../Apache.Ignite.AspNet/IgniteSessionStateStoreProvider.cs    | 6 +++---
 .../dotnet/Apache.Ignite.Core/Impl/Cache/CacheImpl.cs          | 2 +-
 .../dotnet/Apache.Ignite.Core/Impl/Cache/CacheInvokeOp.cs      | 2 +-
 .../dotnet/Apache.Ignite.Core/Impl/Cache/ICacheInternal.cs     | 6 +++---
 4 files changed, 8 insertions(+), 8 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/ignite/blob/0e2d5121/modules/platforms/dotnet/Apache.Ignite.AspNet/IgniteSessionStateStoreProvider.cs
----------------------------------------------------------------------
diff --git a/modules/platforms/dotnet/Apache.Ignite.AspNet/IgniteSessionStateStoreProvider.cs b/modules/platforms/dotnet/Apache.Ignite.AspNet/IgniteSessionStateStoreProvider.cs
index 59c1fe1..a502450 100644
--- a/modules/platforms/dotnet/Apache.Ignite.AspNet/IgniteSessionStateStoreProvider.cs
+++ b/modules/platforms/dotnet/Apache.Ignite.AspNet/IgniteSessionStateStoreProvider.cs
@@ -431,7 +431,7 @@ namespace Apache.Ignite.AspNet
         /// </summary>
         private SessionStateLockResult LockItem(string key, long lockId)
         {
-            return ((ICacheInternal) Cache).Invoke<SessionStateLockResult>(CacheInvokeOp.SessionLock, w =>
+            return ((ICacheInternal) Cache).InvokeExtension<SessionStateLockResult>(CacheInvokeOp.SessionLock, w =>
             {
                 w.WriteString(key);
                 WriteLockInfo(w, lockId, true);
@@ -443,7 +443,7 @@ namespace Apache.Ignite.AspNet
         /// </summary>
         private void UnlockItem(string key, long lockId)
         {
-            ((ICacheInternal) Cache).Invoke<object>(CacheInvokeOp.SessionSetAndUnlock, w =>
+            ((ICacheInternal) Cache).InvokeExtension<object>(CacheInvokeOp.SessionSetAndUnlock, w =>
             {
                 w.WriteString(key);
                 w.WriteBoolean(false);  // Only unlock.
@@ -460,7 +460,7 @@ namespace Apache.Ignite.AspNet
 
             var cache = _expiryCacheHolder.GetCacheWithExpiry(data.Timeout * 60);
 
-            ((ICacheInternal) cache).Invoke<object>(CacheInvokeOp.SessionSetAndUnlock, w =>
+            ((ICacheInternal) cache).InvokeExtension<object>(CacheInvokeOp.SessionSetAndUnlock, w =>
             {
                 w.WriteString(key);
                 w.WriteBoolean(true);  // Unlock and update.

http://git-wip-us.apache.org/repos/asf/ignite/blob/0e2d5121/modules/platforms/dotnet/Apache.Ignite.Core/Impl/Cache/CacheImpl.cs
----------------------------------------------------------------------
diff --git a/modules/platforms/dotnet/Apache.Ignite.Core/Impl/Cache/CacheImpl.cs b/modules/platforms/dotnet/Apache.Ignite.Core/Impl/Cache/CacheImpl.cs
index 75a4871..871b435 100644
--- a/modules/platforms/dotnet/Apache.Ignite.Core/Impl/Cache/CacheImpl.cs
+++ b/modules/platforms/dotnet/Apache.Ignite.Core/Impl/Cache/CacheImpl.cs
@@ -873,7 +873,7 @@ namespace Apache.Ignite.Core.Impl.Cache
         }
 
         /** <inheritDoc /> */
-        public T Invoke<T>(CacheInvokeOp opCode, Action<IBinaryRawWriter> writeAction)
+        public T InvokeExtension<T>(CacheInvokeOp opCode, Action<IBinaryRawWriter> writeAction)
         {
             return DoOutInOpX((int) CacheOp.Extension, writer =>
                 {

http://git-wip-us.apache.org/repos/asf/ignite/blob/0e2d5121/modules/platforms/dotnet/Apache.Ignite.Core/Impl/Cache/CacheInvokeOp.cs
----------------------------------------------------------------------
diff --git a/modules/platforms/dotnet/Apache.Ignite.Core/Impl/Cache/CacheInvokeOp.cs b/modules/platforms/dotnet/Apache.Ignite.Core/Impl/Cache/CacheInvokeOp.cs
index 15329c3..4b52d53 100644
--- a/modules/platforms/dotnet/Apache.Ignite.Core/Impl/Cache/CacheInvokeOp.cs
+++ b/modules/platforms/dotnet/Apache.Ignite.Core/Impl/Cache/CacheInvokeOp.cs
@@ -18,7 +18,7 @@
 namespace Apache.Ignite.Core.Impl.Cache
 {
     /// <summary>
-    /// Op codes for <see cref="ICacheInternal.Invoke{T}"/>.
+    /// Op codes for <see cref="ICacheInternal.InvokeExtension{T}"/>.
     /// </summary>
     public enum CacheInvokeOp
     {

http://git-wip-us.apache.org/repos/asf/ignite/blob/0e2d5121/modules/platforms/dotnet/Apache.Ignite.Core/Impl/Cache/ICacheInternal.cs
----------------------------------------------------------------------
diff --git a/modules/platforms/dotnet/Apache.Ignite.Core/Impl/Cache/ICacheInternal.cs b/modules/platforms/dotnet/Apache.Ignite.Core/Impl/Cache/ICacheInternal.cs
index 19c1bfa..43477e8 100644
--- a/modules/platforms/dotnet/Apache.Ignite.Core/Impl/Cache/ICacheInternal.cs
+++ b/modules/platforms/dotnet/Apache.Ignite.Core/Impl/Cache/ICacheInternal.cs
@@ -38,14 +38,14 @@ namespace Apache.Ignite.Core.Impl.Cache
         IQueryCursor<T> QueryFields<T>(SqlFieldsQuery qry, Func<IBinaryRawReader, int, T> readerFunc);
 
         /// <summary>
         /// Invokes a cache operation by code.
         /// </summary>
         /// <typeparam name="T">The type of the result.</typeparam>
-        /// <param name="opCode">The operation code.</param>
+        /// <param name="opCode">The extension op code.</param>
         /// <param name="writeAction">The write action.</param>
         /// <returns>
         /// Result of the processing.
         /// </returns>
-        T Invoke<T>(CacheInvokeOp opCode, Action<IBinaryRawWriter> writeAction);
+        T InvokeExtension<T>(CacheInvokeOp opCode, Action<IBinaryRawWriter> writeAction);
     }
 }
@@ -38,14 +38,14 @@ namespace Apache.Ignite.Core.Impl.Cache
 
         /// <summary>
-        /// Invokes a cache operation by code.
+        /// Invokes a cache extension.
         /// </summary>
         /// <typeparam name="T">The type of the result.</typeparam>